import sys

from .serializer_factory import SerializerFactory


def main():
    args = sys.argv

    if len(args) != 5:
        print("Invalid amount of arguments")
        exit()

    _, filepath_from, filepath_to, format_from, format_to = args

    try:
        from_serializer = SerializerFactory.serializer(format_from)
        to_serializer = SerializerFactory.serializer(format_to)
    except Exception as e:
        print(e)
        exit()

    try:
        with open(filepath_from, 'r') as file_from, open(filepath_to, 'w') as file_to:
            des_obj = from_serializer.load(file_from)
            to_serializer.dump(des_obj, file_to)
    except Exception as e:
        print(e)
        exit()



from typing import Literal

from .serializers import json_serializer, xml_serializer


class SerializerFactory:
    @staticmethod
    def serializer(serializer_type: Literal['xml', 'json']):
        if serializer_type == 'xml':
            return xml_serializer
        elif serializer_type == 'json':
            return json_serializer
        else:
            raise Exception("Unknown serializer type")



from setuptools import setup

setup(
    name='dubinka-custom-serializer',
    version='0.0.5',
    packages=['custom_serializer'],
    entry_points={
        "console_scripts": [
            "custom-serialize = custom_serializer.custom_serializer:main"
        ]
    },
    url='',
    license='',
    author='misha-rab-ymniy',
    author_email='',
    description=''
)
